@@ -26,12 +26,12 @@ class IntegrationsOrganizationModel(IntegrationsModel):
     organization: uuid.UUID = Field(index=True)
 
 
-## Jobs
-class JobsModel(BaseModel):
+## Vacancies
+class VacanciesModel(BaseModel):
     pass
 
 
-class JobsOrganizationModel(JobsModel):
+class VacanciesOrganizationModel(VacanciesModel):
     organization: uuid.UUID = Field(index=True)
 
 
